@@ -781,6 +781,7 @@ where
     #[emitter]
     fn emit_value(&mut self, n: &Value) -> Result {
         match n {
+            Value::ComponentValue(n) => emit!(self, n),
             Value::Function(n) => emit!(self, n),
             Value::SimpleBlock(n) => emit!(self, n),
             Value::Dimension(n) => emit!(self, n),
@@ -893,7 +894,7 @@ where
                 ComponentValue::Rule(_) | ComponentValue::KeyframeBlock(_) => {
                     formatting_newline!(self);
                 }
-                ComponentValue::DeclarationBlockItem(_) if idx == 0 => {
+                ComponentValue::DeclarationOrAtRule(_) if idx == 0 => {
                     formatting_newline!(self);
                 }
                 _ => {}
@@ -925,11 +926,11 @@ where
                         formatting_newline!(self);
                     }
                 }
-                ComponentValue::DeclarationBlockItem(i) => match i {
-                    DeclarationBlockItem::AtRule(_) => {
+                ComponentValue::DeclarationOrAtRule(i) => match i {
+                    DeclarationOrAtRule::AtRule(_) => {
                         formatting_newline!(self);
                     }
-                    DeclarationBlockItem::Declaration(_) => {
+                    DeclarationOrAtRule::Declaration(_) => {
                         if idx != len - 1 {
                             semi!(self);
                         } else {
@@ -938,13 +939,14 @@ where
 
                         formatting_newline!(self);
                     }
-                    DeclarationBlockItem::Invalid(_) => {}
+                    DeclarationOrAtRule::Invalid(_) => {}
                 },
                 ComponentValue::Value(_) => {
                     if ending == ']' && idx != len - 1 {
                         space!(self);
                     }
                 }
+                _ => {}
             }
         }
 
@@ -954,8 +956,11 @@ where
     #[emitter]
     fn emit_component_value(&mut self, n: &ComponentValue) -> Result {
         match n {
+            ComponentValue::PreservedToken(n) => emit!(self, n),
+            ComponentValue::Function(n) => emit!(self, n),
+            ComponentValue::SimpleBlock(n) => emit!(self, n),
             ComponentValue::StyleBlock(n) => emit!(self, n),
-            ComponentValue::DeclarationBlockItem(n) => emit!(self, n),
+            ComponentValue::DeclarationOrAtRule(n) => emit!(self, n),
             ComponentValue::Rule(n) => emit!(self, n),
             ComponentValue::Value(n) => emit!(self, n),
             ComponentValue::KeyframeBlock(n) => emit!(self, n),
@@ -973,11 +978,11 @@ where
     }
 
     #[emitter]
-    fn emit_declaration_block_item(&mut self, n: &DeclarationBlockItem) -> Result {
+    fn emit_declaration_block_item(&mut self, n: &DeclarationOrAtRule) -> Result {
         match n {
-            DeclarationBlockItem::Declaration(n) => emit!(self, n),
-            DeclarationBlockItem::AtRule(n) => emit!(self, n),
-            DeclarationBlockItem::Invalid(n) => emit!(self, n),
+            DeclarationOrAtRule::Declaration(n) => emit!(self, n),
+            DeclarationOrAtRule::AtRule(n) => emit!(self, n),
+            DeclarationOrAtRule::Invalid(n) => emit!(self, n),
         }
     }
 
